==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorListBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorListBuilder extends io.fabric8.openshift.api.model.operatorhub.v1.OperatorListFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1.OperatorListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1.OperatorList,io.fabric8.openshift.api.model.operatorhub.v1.OperatorListBuilder>{
  public OperatorListBuilder() {
    this(false);
  }
  public OperatorListBuilder(java.lang.Boolean validationEnabled) {
    this(new OperatorList(), validationEnabled);
  }
  public OperatorListBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorListFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorListBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OperatorList(), validationEnabled);
  }
  public OperatorListBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorListFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorList instance) {
    this(fluent, instance, false);
  }
  public OperatorListBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorListFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OperatorListBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorList instance) {
    this(instance,false);
  }
  public OperatorListBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1.OperatorListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorList build() {
    OperatorList buildable = new OperatorList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorListBuilder that = (OperatorListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-6.4.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorListBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OperatorListBuilder extends OperatorListFluentImpl<OperatorListBuilder> implements VisitableBuilder<OperatorList,OperatorListBuilder>{
  public OperatorListBuilder() {
    this(false);
  }
  public OperatorListBuilder(Boolean validationEnabled) {
    this(new OperatorList(), validationEnabled);
  }
  public OperatorListBuilder(OperatorListFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorListBuilder(OperatorListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OperatorList(), validationEnabled);
  }
  public OperatorListBuilder(OperatorListFluent<?> fluent,OperatorList instance) {
    this(fluent, instance, false);
  }
  public OperatorListBuilder(OperatorListFluent<?> fluent,OperatorList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OperatorListBuilder(OperatorList instance) {
    this(instance,false);
  }
  public OperatorListBuilder(OperatorList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  OperatorListFluent<?> fluent;
  Boolean validationEnabled;
  public OperatorList build() {
    OperatorList buildable = new OperatorList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
